##  Accessing the 6R Attribute in Fact Sheets
In meta model v4 workspaces, the 6R Classification field is a default attribute of the Application Fact Sheet. If your workspace is not aligned with meta model v4, you can implement the 6R assessment by adding the 6R Classification attribute as a custom field.
In meta model v3 workspaces, the 6R attribute can be added to your workspace through Optional Feature and Early Access under Admin settings. As an Admin of a workspace, you do the following:
  1. Go to the Administration page.
  2. Open the Optional Feature & Early Access tab
  3. Click Activate on the Portfolio Strategy![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2750f02e7a4410149250ffaa19ea8e45_LowRes.png)
  4. Now, when you open your Inventory and go to one of your Application Fact Sheets, you can see the new section that has been added.![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27412e497a441014a9b29d95c5ab6807_LowRes.png)
